<?php

class CarerixSearchWidget extends WP_Widget {
    /**
     * List of fields with default value
     * @var array
     */
    protected $default_field_values;
    
    public function __construct() {
        $labels = Utils_Labels::get();
        $this->default_field_values = array(
            'title' => $labels['general.message.field.newTitle'],
            'number' => 1,
            'search_by_radius' => 1,
            'postal_code' => 1,
            'country' => 1,
            'functiongroup' => 1,
            'functiongroupsort' => 0
        );
        
        parent::__construct('carerix_search_widget', 'Carerix Search', array(
            'description' => 'Widget to search the Carerix system for publications'
        ));
    }

    public function widget($args, $instance) {
        foreach($this->default_field_values as $field_name => $field_value) {
            if (!isset($instance[$field_name])) {
                $instance[$field_name] = $field_value;
            }
        }
        
        $data = array(
            'widget_args' => $args,
            'field_values' => $instance
        );

        if ($instance['country']) {
            $countries = Entity_Form_EmployeeApply::get_system_select_options('Country');
            $data['countries'] = $countries;
        }
        
        if ($instance['functiongroup']) {
            $functions = Entity_Form_EmployeeApply::get_system_select_options('Function0');
            
            if ($instance['functiongroupsort']) {
                usort($functions, array($this, "sortFunctionsAlpha"));
            }
            $data['functions'] = $functions;
        }
        
        $search_template = new Utils_Template('frontend/forms/search');
        $search_template->with($data)->display();
    }

    public function form($instance) {
        $field_settings = array();
        foreach ($this->default_field_values as $field_name => $field_value) {
            $field_settings[$field_name] = array(
                'id' => $this->get_field_id($field_name),
                'name' => $this->get_field_name($field_name),
                'value' => isset($instance[$field_name]) ? $instance[$field_name] : $field_value
            );
        }
        
        $search_template = new Utils_Template('admin/forms/search');
        $search_template->with(array(
            'field_settings' => $field_settings
        ))->display();
    }

    public function update($new_instance, $old_instance) {
        $instance = array();
        
        foreach ($this->default_field_values as $field_name => $value) {
            $instance[$field_name] = isset($new_instance[$field_name]) ? strip_tags($new_instance[$field_name]) : '';
        }
        return $instance;
    }

    private function sortFunctionsAlpha($a, $b) {
        return strcasecmp($a['label'], $b['label']);
    }
}
