<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Sep 4, 2013 11:20:34 AM
 * @version $Rev$
 */


/**
 * Labels class
 * Used to ....
 */
class Utils_Labels {
	
	private static $alternates = array(
		'en-US' => array('en-GB'),
		'en'	=> array('en-GB'),
		'de'	=> array('de-DE'),
		'es'	=> array('es-ES'),
		'fr'	=> array('fr-FR'),
		'nl'	=> array('nl-NL'),
	);
	
	private function __construct() {
		;
	}
	
	static function get($language = FALSE)
	{
		if($language === FALSE)
		{
			$interfacer = WP_Interfacer::getInstance();
			$current_language = $interfacer->language_current();	
		}
		else
		{
			$current_language = trim($language);
		}
		
		$filename = self::get_resource_file_name($current_language);
		if($filename === FALSE)
		{
			$current_language = WP_Constants::DEFAULT_LANGUAGE_CODE;
			$filename = self::get_resource_file_name($current_language);
		}
		
		return self::process_resources($filename);
	}
	
	private static function get_resource_file_name($language)
	{
		$directory = CARERIX_INSTALL_DIR . DIRECTORY_SEPARATOR . 'assets' . DIRECTORY_SEPARATOR . 'resources';
		
		$filename = $language . '.resources.php';
		
		if(file_exists($directory . DIRECTORY_SEPARATOR . $filename))
		{
			return $directory . DIRECTORY_SEPARATOR . $filename;
		}
		
		
		$languageIndex = self::get_major_language($language);
        if(!$languageIndex) $languageIndex = 'en';
        if(!isset(self::$alternates[$languageIndex])) $languageIndex = 'en';
        
		foreach(self::$alternates[$languageIndex] as $alternate_language)
		{
			$filename = $alternate_language . '.resources.php';
		
			if(file_exists($directory . DIRECTORY_SEPARATOR . $filename))
			{
				return $directory . DIRECTORY_SEPARATOR . $filename;
			}
		}
		
		return false;
	}
	
	private static function process_resources($filename)
	{
		$data = parse_ini_file($filename, true);
		$labels = array();

		foreach($data as $section => $values)
		{
			foreach($values as $key => $value)
			{
				$labels[$section . '.' . $key] = $value;
			}
		}
        
		return $labels;
	}
	
	private static function get_major_language($language)
	{
		$separators = array('-', '_');
		
		foreach($separators as $separator)
		{
			if(stripos($language, $separator) !== false)
			{
				$_t = explode($separator,$language);
				return $_t[0];
			}			
		}
		return $language;
	}
}